import os
import sys

# -*- coding: utf-8 -*-
#
# Configuration file for the Sphinx documentation builder.
#
# This file does only contain a selection of the most common options. For a
# full list see the documentation:
# http://www.sphinx-doc.org/en/master/config

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = 'platypush'
copyright = '2017-2019, Fabio Manganiello'
author = 'Fabio Manganiello'

# The short X.Y version
version = ''
# The full version, including alpha/beta/rc tags
release = ''


# -- General configuration ---------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.intersphinx',
    'sphinx.ext.todo',
    'sphinx.ext.imgmath',
    'sphinx.ext.ifconfig',
    'sphinx.ext.viewcode',
    'sphinx.ext.githubpages',
    'sphinx_rtd_theme',
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path .
exclude_patterns = []

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
# html_theme = 'haiku'
html_theme = 'sphinx_rtd_theme'

html_domain_indices = True

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
# html_theme_options = {}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
# html_static_path = ['_static']

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# The default sidebars (for documents that don't match any pattern) are
# defined by theme itself.  Builtin themes are using these templates by
# default: ``['localtoc.html', 'relations.html', 'sourcelink.html',
# 'searchbox.html']``.
#
# html_sidebars = {}


# -- Options for HTMLHelp output ---------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = 'platypushdoc'


# -- Options for LaTeX output ------------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',

    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',

    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',

    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (master_doc, 'platypush.tex', 'platypush Documentation',
     'BlackLight', 'manual'),
]


# -- Options for manual page output ------------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, 'platypush', 'platypush Documentation',
     [author], 1)
]


# -- Options for Texinfo output ----------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (master_doc, 'platypush', 'platypush Documentation',
     author, 'platypush', 'One line description of project.',
     'Miscellaneous'),
]


# -- Extension configuration -------------------------------------------------

# -- Options for intersphinx extension ---------------------------------------

# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {'https://docs.python.org/': None}

# -- Options for todo extension ----------------------------------------------

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = True

autodoc_mock_imports = ['googlesamples.assistant.grpc.audio_helpers',
                        'google.assistant.embedded',
                        'google.assistant.library',
                        'google.assistant.library.event',
                        'google.assistant.library.file_helpers',
                        'google.oauth2.credentials',
                        'oauth2client',
                        'apiclient',
                        'tenacity',
                        'smartcard',
                        'Leap',
                        'oauth2client',
                        'rtmidi',
                        'bluetooth',
                        'gevent.wsgi',
                        'Adafruit_IO',
                        'pyperclip',
                        'dbus',
                        'inputs',
                        'inotify',
                        'omxplayer',
                        'plexapi',
                        'cwiid',
                        'sounddevice',
                        'soundfile',
                        'numpy',
                        'cv2',
                        'nfc',
                        'ndef',
                        'bcrypt',
                        'google',
                        'feedparser',
                        'kafka',
                        'googlesamples',
                        'icalendar',
                        'httplib2',
                        'mpd',
                        'serial',
                        'pyHS100',
                        'grpc',
                        'envirophat',
                        'gps',
                        'picamera',
                        'pwm3901',
                        'PIL',
                        'croniter',
                        'pyaudio',
                        'avs',
                        'PyOBEX',
                        'todoist',
                        'trello',
                        'telegram',
                        'telegram.ext',
                        'pyfirmata2',
                        'cups',
                        'graphyte',
                        'cpuinfo',
                        'psutil',
                        'openzwave',
                        'deepspeech',
                        'wave',
                        'pvporcupine ',
                        'pvcheetah',
                        'pyotp',
                        'linode_api4',
                        'pyzbar',
                        'tensorflow',
                        'keras',
                        'pandas',
                        'samsungtvws',
                        'paramiko',
                        'luma',
                        'zeroconf',
                        'dbus',
                        'gi',
                        'gi.repository',
                        'twilio',
                        'pytz',
                        'Adafruit_Python_DHT',
                        'RPi.GPIO',
                        'RPLCD',
                        'imapclient',
                        ]

sys.path.insert(0, os.path.abspath('../..'))

def skip(app, what, name, obj, skip, options):
    if name == "__init__":
        return False
    return skip

def setup(app):
    app.connect("autodoc-skip-member", skip)

